Welcome to UEVaultManager
=========================

|pypi| |py_versions| |github| |docs|

.. |pypi| image:: https://img.shields.io/pypi/v/uevaultmanager
    :target: https://pypi.python.org/pypi/uevaultmanager
    :alt: Current PyPi Version

.. |py_versions| image:: https://img.shields.io/pypi/pyversions/uevaultmanager
    :target: https://pypi.python.org/pypi/uevaultmanager
    :alt: Supported Python Versions

.. |github| image:: https://img.shields.io/github/v/tag/LaurentOngaro/uevaultmanager
    :target: https://github.com/LaurentOngaro/UEVaultManager

.. |docs| image:: https://img.shields.io/readthedocs/uevaultmanager/latest
   :target:  https://uevaultmanager.readthedocs.io/en/latest/?badge=latest


**UEVaultManager** is an open-source assets manager that can list assets and
their data from the Epic Games Marketplace. It is developed in Python, so
it can run on any platform that support this language.

Its main purpose is to list the assets (with or without user login),
filter (optional) and save the list into a file that can be reused later
as a data source (in an Excel sheet for instance).

**This project is under active development**

To go further, dive into `the documentation <https://uevaultmanager.readthedocs.io/en/latest/index.html>`_ or just go for `a quickstart <https://uevaultmanager.readthedocs.io/en/latest/quickstart.html>`_
